@@ -5,5 +5,5 @@ allIntersect <- function(sets, pow2) {
         stop("argument must be list of integer vectors")
     if (missing(pow2))
         pow2 <- ceiling(log2(100 * max(sapply(sets, length))))
-    .Call("all_intersect", sets, as.integer(pow2), PACKAGE = "rcdd")
+    .Call(C_all_intersect, sets, as.integer(pow2))
 }
