@@ -9,11 +9,11 @@ redundant <- function(input, representation = c("H", "V")) {
     validcdd(input, representation)
 
     if (is.character(input)) {
-        .Call("redundant", input, h, PACKAGE = "rcdd")
+        .Call(C_redundant, input, h)
     } else {
         if (! is.numeric(input))
             stop("input must be numeric or character")
         storage.mode(input) <- "double"
-        .Call("redundant_f", input, h, PACKAGE = "rcdd")
+        .Call(C_redundant_f, input, h)
     }
 }
