@@ -13,6 +13,6 @@ void die(const char *format, ...)
     vsnprintf(buf, BUFSIZE, format, arg);
     va_end(arg);
     buf[BUFSIZE - 1] = '\0';
-    error(buf);
+    error("%s", buf);
 }
 
